CCA2

Enum CCA2 

#[repr(u8)]
pub enum CCA2 {
Show 250 variants AF = 0, AX = 1, AL = 2, DZ = 3, AS = 4, AD = 5, AO = 6, AI = 7, AQ = 8, AG = 9, AR = 10, AM = 11, AW = 12, AU = 13, AT = 14, AZ = 15, BS = 16, BH = 17, BD = 18, BB = 19, BY = 20, BE = 21, BZ = 22, BJ = 23, BM = 24, BT = 25, BO = 26, BA = 27, BW = 28, BV = 29, BR = 30, IO = 31, VG = 32, BN = 33, BG = 34, BF = 35, BI = 36, KH = 37, CM = 38, CA = 39, CV = 40, BQ = 41, KY = 42, CF = 43, TD = 44, CL = 45, CN = 46, CX = 47, CC = 48, CO = 49, KM = 50, CK = 51, CR = 52, CI = 53, HR = 54, CU = 55, CW = 56, CY = 57, CZ = 58, DK = 59, DJ = 60, DM = 61, DO = 62, CD = 63, EC = 64, EG = 65, SV = 66, GQ = 67, ER = 68, EE = 69, SZ = 70, ET = 71, FK = 72, FO = 73, FJ = 74, FI = 75, FR = 76, GF = 77, PF = 78, TF = 79, GA = 80, GM = 81, GE = 82, DE = 83, GH = 84, GI = 85, GR = 86, GL = 87, GD = 88, GP = 89, GU = 90, GT = 91, GG = 92, GN = 93, GW = 94, GY = 95, HT = 96, HM = 97, HN = 98, HK = 99, HU = 100, IS = 101, IN = 102, ID = 103, IR = 104, IQ = 105, IE = 106, IM = 107, IL = 108, IT = 109, JM = 110, JP = 111, JE = 112, JO = 113, KZ = 114, KE = 115, KI = 116, XK = 117, KW = 118, KG = 119, LA = 120, LV = 121, LB = 122, LS = 123, LR = 124, LY = 125, LI = 126, LT = 127, LU = 128, MO = 129, MG = 130, MW = 131, MY = 132, MV = 133, ML = 134, MT = 135, MH = 136, MQ = 137, MR = 138, MU = 139, YT = 140, MX = 141, FM = 142, MD = 143, MC = 144, MN = 145, ME = 146, MS = 147, MA = 148, MZ = 149, MM = 150, NA = 151, NR = 152, NP = 153, NL = 154, NC = 155, NZ = 156, NI = 157, NE = 158, NG = 159, NU = 160, NF = 161, KP = 162, MK = 163, MP = 164, NO = 165, OM = 166, PK = 167, PW = 168, PS = 169, PA = 170, PG = 171, PY = 172, PE = 173, PH = 174, PN = 175, PL = 176, PT = 177, PR = 178, QA = 179, CG = 180, RE = 181, RO = 182, RU = 183, RW = 184, BL = 185, SH = 186, KN = 187, LC = 188, MF = 189, PM = 190, VC = 191, WS = 192, SM = 193, ST = 194, SA = 195, SN = 196, RS = 197, SC = 198, SL = 199, SG = 200, SX = 201, SK = 202, SI = 203, SB = 204, SO = 205, ZA = 206, GS = 207, KR = 208, SS = 209, ES = 210, LK = 211, SD = 212, SR = 213, SJ = 214, SE = 215, CH = 216, SY = 217, TW = 218, TJ = 219, TZ = 220, TH = 221, TL = 222, TG = 223, TK = 224, TO = 225, TT = 226, TN = 227, TR = 228, TM = 229, TC = 230, TV = 231, UG = 232, UA = 233, AE = 234, GB = 235, US = 236, UM = 237, VI = 238, UY = 239, UZ = 240, VU = 241, VA = 242, VE = 243, VN = 244, WF = 245, EH = 246, YE = 247, ZM = 248, ZW = 249,
}
ISO 3166-1 alpha-2 code in enum.

Variants



AF = 0

Islamic Republic of Afghanistan



AX = 1

Åland Islands



AL = 2

Republic of Albania



DZ = 3

People’s Democratic Republic of Algeria



AS = 4

American Samoa



AD = 5

Principality of Andorra



AO = 6

Republic of Angola



AI = 7

Anguilla



AQ = 8

Antarctica



AG = 9

Antigua and Barbuda



AR = 10

Argentine Republic



AM = 11

Republic of Armenia



AW = 12

Aruba



AU = 13

Commonwealth of Australia



AT = 14

Republic of Austria



AZ = 15

Republic of Azerbaijan



BS = 16

Commonwealth of the Bahamas



BH = 17

Kingdom of Bahrain



BD = 18

People’s Republic of Bangladesh



BB = 19

Barbados



BY = 20

Republic of Belarus



BE = 21

Kingdom of Belgium



BZ = 22

Belize



BJ = 23

Republic of Benin



BM = 24

Bermuda



BT = 25

Kingdom of Bhutan



BO = 26

Plurinational State of Bolivia



BA = 27

Bosnia and Herzegovina



BW = 28

Republic of Botswana



BV = 29

Bouvet Island



BR = 30

Federative Republic of Brazil



IO = 31

British Indian Ocean Territory



VG = 32

Virgin Islands



BN = 33

Nation of Brunei, Abode of Peace



BG = 34

Republic of Bulgaria



BF = 35

Burkina Faso



BI = 36

Republic of Burundi



KH = 37

Kingdom of Cambodia



CM = 38

Republic of Cameroon



CA = 39

Canada



CV = 40

Republic of Cabo Verde



BQ = 41

Bonaire, Sint Eustatius and Saba



KY = 42

Cayman Islands



CF = 43

Central African Republic



TD = 44

Republic of Chad



CL = 45

Republic of Chile



CN = 46

People’s Republic of China



CX = 47

Territory of Christmas Island



CC = 48

Territory of the Cocos (Keeling) Islands



CO = 49

Republic of Colombia



KM = 50

Union of the Comoros



CK = 51

Cook Islands



CR = 52

Republic of Costa Rica



CI = 53

Republic of Côte d’Ivoire



HR = 54

Republic of Croatia



CU = 55

Republic of Cuba



CW = 56

Country of Curaçao



CY = 57

Republic of Cyprus



CZ = 58

Czech Republic



DK = 59

Kingdom of Denmark



DJ = 60

Republic of Djibouti



DM = 61

Commonwealth of Dominica



DO = 62

Dominican Republic



CD = 63

Democratic Republic of the Congo



EC = 64

Republic of Ecuador



EG = 65

Arab Republic of Egypt



SV = 66

Republic of El Salvador



GQ = 67

Republic of Equatorial Guinea



ER = 68

State of Eritrea



EE = 69

Republic of Estonia



SZ = 70

Kingdom of Eswatini



ET = 71

Federal Democratic Republic of Ethiopia



FK = 72

Falkland Islands



FO = 73

Faroe Islands



FJ = 74

Republic of Fiji



FI = 75

Republic of Finland



FR = 76

French Republic



GF = 77

Guiana



PF = 78

French Polynesia



TF = 79

Territory of the French Southern and Antarctic Lands



GA = 80

Gabonese Republic



GM = 81

Republic of the Gambia



GE = 82

Georgia



DE = 83

Federal Republic of Germany



GH = 84

Republic of Ghana



GI = 85

Gibraltar



GR = 86

Hellenic Republic



GL = 87

Greenland



GD = 88

Grenada



GP = 89

Guadeloupe



GU = 90

Guam



GT = 91

Republic of Guatemala



GG = 92

Bailiwick of Guernsey



GN = 93

Republic of Guinea



GW = 94

Republic of Guinea-Bissau



GY = 95

Co-operative Republic of Guyana



HT = 96

Republic of Haiti



HM = 97

Heard Island and McDonald Islands



HN = 98

Republic of Honduras



HK = 99

Hong Kong Special Administrative Region of the People’s Republic of China



HU = 100

Hungary



IS = 101

Iceland



IN = 102

Republic of India



ID = 103

Republic of Indonesia



IR = 104

Islamic Republic of Iran



IQ = 105

Republic of Iraq



IE = 106

Republic of Ireland



IM = 107

Isle of Man



IL = 108

State of Israel



IT = 109

Italian Republic



JM = 110

Jamaica



JP = 111

Japan



JE = 112

Bailiwick of Jersey



JO = 113

Hashemite Kingdom of Jordan



KZ = 114

Republic of Kazakhstan



KE = 115

Republic of Kenya



KI = 116

Independent and Sovereign Republic of Kiribati



XK = 117

Republic of Kosovo



KW = 118

State of Kuwait



KG = 119

Kyrgyz Republic



LA = 120

Lao People’s Democratic Republic



LV = 121

Republic of Latvia



LB = 122

Lebanese Republic



LS = 123

Kingdom of Lesotho



LR = 124

Republic of Liberia



LY = 125

State of Libya



LI = 126

Principality of Liechtenstein



LT = 127

Republic of Lithuania



LU = 128

Grand Duchy of Luxembourg



MO = 129

Macao Special Administrative Region of the People’s Republic of China



MG = 130

Republic of Madagascar



MW = 131

Republic of Malawi



MY = 132

Malaysia



MV = 133

Republic of the Maldives



ML = 134

Republic of Mali



MT = 135

Republic of Malta



MH = 136

Republic of the Marshall Islands



MQ = 137

Martinique



MR = 138

Islamic Republic of Mauritania



MU = 139

Republic of Mauritius



YT = 140

Department of Mayotte



MX = 141

United Mexican States



FM = 142

Federated States of Micronesia



MD = 143

Republic of Moldova



MC = 144

Principality of Monaco



MN = 145

Mongolia



ME = 146

Montenegro



MS = 147

Montserrat



MA = 148

Kingdom of Morocco



MZ = 149

Republic of Mozambique



MM = 150

Republic of the Union of Myanmar



NA = 151

Republic of Namibia



NR = 152

Republic of Nauru



NP = 153

Federal Democratic Republic of Nepal



NL = 154

Kingdom of the Netherlands



NC = 155

New Caledonia



NZ = 156

New Zealand



NI = 157

Republic of Nicaragua



NE = 158

Republic of Niger



NG = 159

Federal Republic of Nigeria



NU = 160

Niue



NF = 161

Territory of Norfolk Island



KP = 162

Democratic People’s Republic of Korea



MK = 163

Republic of North Macedonia



MP = 164

Commonwealth of the Northern Mariana Islands



NO = 165

Kingdom of Norway



OM = 166

Sultanate of Oman



PK = 167

Islamic Republic of Pakistan



PW = 168

Republic of Palau



PS = 169

State of Palestine



PA = 170

Republic of Panama



PG = 171

Independent State of Papua New Guinea



PY = 172

Republic of Paraguay



PE = 173

Republic of Peru



PH = 174

Republic of the Philippines



PN = 175

Pitcairn Group of Islands



PL = 176

Republic of Poland



PT = 177

Portuguese Republic



PR = 178

Commonwealth of Puerto Rico



QA = 179

State of Qatar



CG = 180

Republic of the Congo



RE = 181

Réunion Island



RO = 182

Romania



RU = 183

Russian Federation



RW = 184

Republic of Rwanda



BL = 185

Collectivity of Saint Barthélemy



SH = 186

Saint Helena, Ascension and Tristan da Cunha



KN = 187

Federation of Saint Christopher and Nevis



LC = 188

Saint Lucia



MF = 189

Saint Martin



PM = 190

Saint Pierre and Miquelon



VC = 191

Saint Vincent and the Grenadines



WS = 192

Independent State of Samoa



SM = 193

Most Serene Republic of San Marino



ST = 194

Democratic Republic of São Tomé and Príncipe



SA = 195

Kingdom of Saudi Arabia



SN = 196

Republic of Senegal



RS = 197

Republic of Serbia



SC = 198

Republic of Seychelles



SL = 199

Republic of Sierra Leone



SG = 200

Republic of Singapore



SX = 201

Sint Maarten



SK = 202

Slovak Republic



SI = 203

Republic of Slovenia



SB = 204

Solomon Islands



SO = 205

Federal Republic of Somalia



ZA = 206

Republic of South Africa



GS = 207

South Georgia and the South Sandwich Islands



KR = 208

Republic of Korea



SS = 209

Republic of South Sudan



ES = 210

Kingdom of Spain



LK = 211

Democratic Socialist Republic of Sri Lanka



SD = 212

Republic of the Sudan



SR = 213

Republic of Suriname



SJ = 214

Svalbard og Jan Mayen



SE = 215

Kingdom of Sweden



CH = 216

Swiss Confederation



SY = 217

Syrian Arab Republic



TW = 218

Republic of China (Taiwan)



TJ = 219

Republic of Tajikistan



TZ = 220

United Republic of Tanzania



TH = 221

Kingdom of Thailand



TL = 222

Democratic Republic of Timor-Leste



TG = 223

Togolese Republic



TK = 224

Tokelau



TO = 225

Kingdom of Tonga



TT = 226

Republic of Trinidad and Tobago



TN = 227

Tunisian Republic



TR = 228

Republic of Turkey



TM = 229

Turkmenistan



TC = 230

Turks and Caicos Islands



TV = 231

Tuvalu



UG = 232

Republic of Uganda



UA = 233

Ukraine



AE = 234

United Arab Emirates



GB = 235

United Kingdom of Great Britain and Northern Ireland



US = 236

United States of America



UM = 237

United States Minor Outlying Islands



VI = 238

Virgin Islands of the United States



UY = 239

Oriental Republic of Uruguay



UZ = 240

Republic of Uzbekistan



VU = 241

Republic of Vanuatu



VA = 242

Vatican City State



VE = 243

Bolivarian Republic of Venezuela



VN = 244

Socialist Republic of Vietnam



WF = 245

Territory of the Wallis and Futuna Islands



EH = 246

Sahrawi Arab Democratic Republic



YE = 247

Republic of Yemen



ZM = 248

Republic of Zambia



ZW = 249

Republic of Zimbabwe

Methods from Deref<Target = Country>

pub async fn graphql_name( &self, _: &Context<'_>, ) -> Result<&'static CountryMeta>

Available on crate features async-graphql and alloc only.

Returns the name metadata of the country

pub async fn graphql_flag(&self, _: &Context<'_>) -> Result<&'static str>

Available on crate features async-graphql and alloc only.

Returns the country’s flag

pub async fn graphql_cca2(&self, _: &Context<'_>) -> Result<&'static str>

Available on crate features async-graphql and alloc only.

Returns ISO 3166-1 alpha-2 code.

pub async fn graphql_cca3(&self, _: &Context<'_>) -> Result<&'static str>

Available on crate features async-graphql and alloc only.

Returns ISO 3166-1 alpha-3 code.

pub async fn graphql_ccn3(&self, _: &Context<'_>) -> Result<&'static str>

Available on crate features async-graphql and alloc only.

Returns ISO 3166-1 numeric code.

pub async fn graphql_ioc(&self, _: &Context<'_>) -> Result<Option<&'static str>>

Available on crate features async-graphql and alloc only.
pub async fn graphql_tld( &self, _: &Context<'_>, ) -> Result<&'static [&'static str]>

Available on crate features async-graphql and alloc only.
pub async fn graphql_locale(&self, _: &Context<'_>) -> Result<&'static Locale>

Available on crate features async-graphql and alloc only.

Returns the country’s locale information

pub async fn graphql_idd(&self, _: &Context<'_>) -> Result<&'static IDD>

Available on crate features async-graphql and alloc only.

Returns the country’s international dialing direct information

pub async fn graphql_geography( &self, _: &Context<'_>, ) -> Result<&'static Geography>

Available on crate features async-graphql and alloc only.

Returns the country’s geographical information

pub async fn graphql_official_languages( &self, _: &Context<'_>, ) -> Result<&'static [&'static Language]>

Available on crate features async-graphql and alloc only.

Returns the country’s official languages information

pub async fn graphql_spoken_languages( &self, _: &Context<'_>, ) -> Result<&'static [&'static str]>

Available on crate features async-graphql and alloc only.

Returns the country’s spoken language codes

pub async fn graphql_currencies( &self, _: &Context<'_>, ) -> Result<&'static [&'static Currency]>

Available on crate features async-graphql and alloc only.

Returns the list of currencies used in the country

pub async fn graphql_subdivisions( &self, _: &Context<'_>, ) -> Result<&'static [&'static Subdivision]>

Available on crate features async-graphql and alloc only.

Returns the subdivisions (states, provinces, etc.) map whose key is ISO 639-3 in the country

pub fn name(&self) -> &'static CountryMeta

Returns the name metadata of the country

pub fn flag(&self) -> &'static str

Returns the country’s flag

pub fn cca2(&self) -> &'static str

Returns ISO 3166-1 alpha-2 code.

pub fn cca3(&self) -> &'static str

Returns ISO 3166-1 alpha-3 code.

pub fn ccn3(&self) -> &'static str

Returns ISO 3166-1 numeric code.

pub fn ioc(&self) -> Option<&'static str>

pub fn tld(&self) -> &'static [&'static str]

pub fn locale(&self) -> &'static Locale

Returns the country’s locale information

pub fn idd(&self) -> &'static IDD

Returns the country’s international dialing direct information

pub fn geography(&self) -> &'static Geography

Returns the country’s geographical information

pub fn official_languages(&self) -> &'static [&'static Language]

Returns the country’s official languages information

pub fn spoken_languages(&self) -> &'static [&'static str]

Returns the country’s spoken language codes

pub fn currencies(&self) -> &'static [&'static Currency]

Returns the list of currencies used in the country

pub fn subdivisions(&self) -> &'static [&'static Subdivision]

Returns the subdivisions (states, provinces, etc.) map whose key is ISO 639-3 in the country